@@ -229,7 +229,7 @@ class MainWindow(Gtk.Window):
         self.rd = rd
         Gtk.Window.__init__(self, title="Rocket Depot", resizable=0)
         self.set_position(Gtk.WindowPosition.CENTER)
-        self.set_border_width(8)
+        self.set_border_width(0)
         self.set_wmclass('rocket-depot', 'rocket-depot')
 
         # Menu bar layout
@@ -259,11 +259,6 @@ class MainWindow(Gtk.Window):
         uimanager.insert_action_group(action_group)
         menubar = uimanager.get_widget("/MenuBar")
 
-        # Grid for widgets in main window
-        grid = Gtk.Grid()
-        grid.set_row_spacing(4)
-        self.add(grid)
-
         # Labels for text entry fields and comboboxes
         hostlabel = Gtk.Label(label="Host")
         userlabel = Gtk.Label(label="Username")
@@ -356,15 +351,39 @@ Useful for diagnosing connection problems''')
         self.connectbutton = Gtk.Button(label="Connect")
         self.connectbutton.connect("clicked", self.enter_connect)
 
+        # Status bar
+        self.status_bar = Gtk.Statusbar()
+
+        # Frame for box provides a border for the grid
+        frame = Gtk.Frame()
+        frame.set_shadow_type(Gtk.ShadowType.NONE)
+        frame.set_border_width(4)
+
+        # Grid for widgets in main window
+        grid = Gtk.Grid()
+        grid.set_row_spacing(4)
+        frame.add(grid)
+
+        # Root box for widgets
+        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=0)
+        box.pack_start(menubar, False, False, 0)
+        self.add(box)
+        box.pack_start(frame, False, False, 0)
+        hseparator = Gtk.HSeparator()
+        box.pack_start(hseparator, False, False, 0)
+        status_box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL, spacing=0)
+        status_box.pack_start(self.status_bar, False, False, 0)
+        status_box.pack_end(self.spinner, False, False, 10)
+        box.pack_end(status_box, False, False, 0)
+
         # Grid to which we attach all of our widgets
-        grid.attach(menubar, 0, 0, 12, 4)
-        grid.attach(hostlabel, 0, 4, 4, 4)
-        grid.attach(userlabel, 0, 8, 4, 4)
-        grid.attach(geometrylabel, 0, 12, 4, 4)
-        grid.attach(clioptionslabel, 0, 16, 4, 4)
-        grid.attach(programlabel, 0, 20, 4, 4)
-        grid.attach(self.homedirbutton, 0, 24, 4, 4)
-        grid.attach(self.terminalbutton, 0, 28, 4, 4)
+        grid.attach(hostlabel, 0, 0, 4, 4)
+        grid.attach(userlabel, 0, 4, 4, 4)
+        grid.attach(geometrylabel, 0, 8, 4, 4)
+        grid.attach(clioptionslabel, 0, 12, 4, 4)
+        grid.attach(programlabel, 0, 16, 4, 4)
+        grid.attach(self.homedirbutton, 0, 20, 4, 4)
+        grid.attach(self.terminalbutton, 0, 24, 4, 4)
         grid.attach_next_to(self.host_combo, hostlabel,
                             Gtk.PositionType.RIGHT, 8, 4)
         grid.attach_next_to(self.userentry, userlabel,
@@ -383,12 +402,10 @@ Useful for diagnosing connection problems''')
                             Gtk.PositionType.RIGHT, 4, 4)
         grid.attach_next_to(self.connectbutton, self.terminalbutton,
                             Gtk.PositionType.RIGHT, 8, 4)
-        grid.attach_next_to(self.spinner, self.terminalbutton,
-                            Gtk.PositionType.RIGHT, 8, 4)
 
         # Load the default profile on startup
-        self.load_settings()
         self.profilename = 'DEFAULT'
+        self.load_settings()
         # Set up Unity quicklist if we can support that
         if unity is True:
             self.create_unity_quicklist()
@@ -454,8 +471,18 @@ Useful for diagnosing connection problems''')
         if not self.rd.options['host']:
             self.on_warn(None, 'No Host', 'No Host or IP Address Given')
         else:
-            self.connectbutton.hide()
-            self.spinner.show()
+            self.status_bar.push(0, 'Connecting to "' + self.rd.options['host'] + '" ...')
+            self.host_combo.set_sensitive(False)
+            self.userentry.set_sensitive(False)
+            self.geometryentry.set_sensitive(False)
+            self.clioptionsentry.set_sensitive(False)
+            self.xfreerdpbutton.set_sensitive(False)
+            self.rdesktopbutton.set_sensitive(False)
+            self.homedirbutton.set_sensitive(False)
+            self.grabkeyboardbutton.set_sensitive(False)
+            self.fullscreenbutton.set_sensitive(False)
+            self.terminalbutton.set_sensitive(False)
+            self.connectbutton.set_sensitive(False)
             self.spinner.start()
             cmdline = self.rd.run_program()
             thread = WorkerThread(self.work_finished_cb, cmdline)
@@ -472,9 +499,19 @@ Useful for diagnosing connection problems''')
         self.start_thread()
 
     def work_finished_cb(self):
+        self.status_bar.pop(0)
         self.spinner.stop()
-        self.spinner.hide()
-        self.connectbutton.show()
+        self.host_combo.set_sensitive(True)
+        self.userentry.set_sensitive(True)
+        self.geometryentry.set_sensitive(True)
+        self.clioptionsentry.set_sensitive(True)
+        self.xfreerdpbutton.set_sensitive(True)
+        self.rdesktopbutton.set_sensitive(True)
+        self.homedirbutton.set_sensitive(True)
+        self.grabkeyboardbutton.set_sensitive(True)
+        self.fullscreenbutton.set_sensitive(True)
+        self.terminalbutton.set_sensitive(True)
+        self.connectbutton.set_sensitive(True)
         error_text = WorkerThread.error_text
         return_code = WorkerThread.return_code
         return_code_ignore = [62, 255]
@@ -574,6 +611,7 @@ Useful for diagnosing connection problems''')
         else:
             self.rd.save_config(self.profilename)
             self.populate_host_combobox()
+            self.status_bar.push(0, 'Host "' + self.rd.options['host'] + '" saved')
             if unity is True:
                 self.clean_unity_quicklist()
 
@@ -596,6 +634,7 @@ Useful for diagnosing connection problems''')
     def save_current_config_as_default(self, widget):
         self.grab_textboxes()
         self.rd.save_config('DEFAULT')
+        self.status_bar.push(0, 'Default host settings saved')
 
     # When the quit button is clicked on the menu bar
     def quit(self, widget):
@@ -636,7 +675,7 @@ Useful for diagnosing connection problems''')
     def on_about(self, widget):
         about = Gtk.AboutDialog()
         about.set_program_name("Rocket Depot")
-        about.set_version("0.23")
+        about.set_version("0.24")
         about.set_copyright("2014 David Roble")
         about.set_comments("rdesktop/xfreerdp Frontend")
         about.set_website("https://github.com/robled/rocket-depot")
@@ -669,6 +708,13 @@ Useful for diagnosing connection problems''')
             self.terminalbutton.set_active(True)
         else:
             self.terminalbutton.set_active(False)
+        self.status_bar_load_host()
+
+    def status_bar_load_host(self):
+        if self.rd.options['host'] == '':
+            self.status_bar.push(0, 'Default host settings loaded')
+        else:
+            self.status_bar.push(0, 'Saved host "' + self.rd.options['host'] + '" loaded')
 
 
 def _main():
@@ -676,8 +722,6 @@ def _main():
     window = MainWindow(rocket_depot)
     window.connect("delete-event", Gtk.main_quit)
     window.show_all()
-    # Hide the progress spinner until it is needed
-    window.spinner.hide()
     Gtk.main()
 
 
